summaryrefslogtreecommitdiffstats
path: root/kword/KWordViewIface.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kword/KWordViewIface.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kword/KWordViewIface.h')
-rw-r--r--kword/KWordViewIface.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kword/KWordViewIface.h b/kword/KWordViewIface.h
index 1404a4b42..ea422ad98 100644
--- a/kword/KWordViewIface.h
+++ b/kword/KWordViewIface.h
@@ -22,7 +22,7 @@
#include <KoViewIface.h>
-#include <qstring.h>
+#include <tqstring.h>
class KWView;
@@ -46,7 +46,7 @@ k_dcop:
void stylist();
void createTemplate();
- int tableSelectCell(const QString &name, uint row, uint col);
+ int tableSelectCell(const TQString &name, uint row, uint col);
void insertTable();
void tableInsertRow();
void tableInsertRow(uint row);
@@ -68,12 +68,12 @@ k_dcop:
* Insert an inline picture at the current character position
* TODO
*/
- void insertInlinePicture( QString fileName, int w = 0, int h = 0 );
+ void insertInlinePicture( TQString fileName, int w = 0, int h = 0 );
/**
* Insert a (non-inline) picture at the given position
* If w and h are 0, the default size from the image is used
*/
- void insertPictureFromFile( QString fileName, double x, double y, int w = 0, int h = 0 );
+ void insertPictureFromFile( TQString fileName, double x, double y, int w = 0, int h = 0 );
void toolsPart();
@@ -100,9 +100,9 @@ k_dcop:
int configTableCols() const;
bool configTableIsFloating() const;
- //it can return QString::null if there is any template selected
- QString configTableTemplateName() const;
- void setConfigTableTemplateName(const QString &_name);
+ //it can return TQString() if there is any template selected
+ TQString configTableTemplateName() const;
+ void setConfigTableTemplateName(const TQString &_name);
void selectAllFrames();
void unSelectAllFrames();
@@ -118,7 +118,7 @@ k_dcop:
void tableProperties();
void importStyle();
- void insertFile(const QString & path);
+ void insertFile(const TQString & path);
void createFrameStyle();
void setPictureInline( bool _inline);
@@ -126,7 +126,7 @@ k_dcop:
void setPictureKeepRatio( bool _keep);
bool pictureKeepRatio() const;
- void changeAutoSpellCheckStatus(bool b);
+ void changeAutoSpellChecktqStatus(bool b);
void deselectAllFrames();
int currentPage();
void convertTableToText();